pub struct Layer<F, L = Base>(/* private fields */);Expand description
One processing layer wrapped around an existing filter chain.
Values of this type are created by Io::add_filter.
F is the outer, newly added layer and L is the previously installed
inner chain.