FilterBuf

Struct FilterBuf 

pub struct FilterBuf<'a> { /* private fields */ }

Implementations

Source

impl FilterBuf<'_>

pub fn io(&self) -> &IoRef

Gets a reference to the I/O object.

pub fn tag(&self) -> &'static str

Gets the I/O tag.

pub fn with_read_src<F, R>(&self, f: F) -> R
where F: FnOnce(&mut Option<BytesMut>) -> R,

Returns references to the source read buffer.

pub fn with_read_buffers<F, R>(&self, f: F) -> R
where F: FnOnce(&mut Option<BytesMut>, &mut BytesMut) -> R,

Returns references to the source and destination read buffers.

pub fn with_write_buffers<F, R>(&self, f: F) -> R
where F: FnOnce(&mut BytePages, &mut BytePages) -> R,

Returns references to the source and destination write buffers.