pub struct FilterBuf<'a> { /* private fields */ }Implementations
Sourceimpl FilterBuf<'_>
impl FilterBuf<'_>
Sourcepub fn with_read_src<F, R>(&self, f: F) -> R
pub fn with_read_src<F, R>(&self, f: F) -> R
Returns references to the source read buffer.
Sourcepub fn with_read_buffers<F, R>(&self, f: F) -> R
pub fn with_read_buffers<F, R>(&self, f: F) -> R
Returns references to the source and destination read buffers.
Sourcepub fn with_write_buffers<F, R>(&self, f: F) -> R
pub fn with_write_buffers<F, R>(&self, f: F) -> R
Returns references to the source and destination write buffers.