pub struct FilterCtx<'a> { /* private fields */ }Implementations
Sourceimpl FilterCtx<'_>
impl FilterCtx<'_>
Sourcepub fn new_read_bytes(&self) -> usize
pub fn new_read_bytes(&self) -> usize
Gets new bytes count for read buffer.
Sourcepub fn with_next<F, R>(&mut self, f: F) -> Rwhere
F: FnOnce(&mut Self) -> R,
pub fn with_next<F, R>(&mut self, f: F) -> Rwhere
F: FnOnce(&mut Self) -> R,
Returns the filter context for the next filter in the chain.
Sourcepub fn with_buffer<F, R>(&mut self, f: F) -> R
pub fn with_buffer<F, R>(&mut self, f: F) -> R
Returns the filter buffer.
Sourcepub fn read_dst_size(&self) -> usize
pub fn read_dst_size(&self) -> usize
Returns the size of the last read buffer in the chain.
Sourcepub fn write_dst_size(&mut self) -> usize
pub fn write_dst_size(&mut self) -> usize
Returns the size of the last write buffer in the chain.